# Tracko
## _Track your series!_

Tracko is an application that you can track the time of the series you've watched till.


## ⚙️ Installation

```sh
pip3 install tracko
```

## ✨ How To Use

First you should setup your account with: 

```sh
tracko setup
```

You can add new series with:

```sh
tracko add
```

You can see all-shelves's series with:

```sh
tracko all-shelves
```

You can see specific shelf's series with:

```sh
tracko shelf
```

You can move a series to a different shelf:

```sh
tracko move
```

You can update a series watched-till time with:

```sh
tracko update
```

You can sign out with:

```sh
tracko signout
```


## 🤝 Contributing

Contributions, issues and feature requests are welcome.<br />
Feel free to check [issues page](https://github.com/revisto/tracko2/issues) if you want to contribute.<br /><br />


## Show your support

Please ⭐️ this repository if this project helped you!


## 📝 License

GNUv2

**Free Software, Hell Yeah!**
